@@ -25,11 +25,13 @@
 #include "config.h"
 #include "rsvg-bpath-util.h"
 
-#include <glib/gmem.h>
-#include <glib/gmessages.h>
+#include <stdio.h>
 #include <math.h>
 #include <string.h>
 
+#include <glib/gmem.h>
+#include <glib/gmessages.h>
+
 /* This is adapted from gnome-canvas-bpath-util in libgnomeprint
    (originally developed as part of Gill). */
 
@@ -42,20 +44,20 @@ rsvg_bpath_def_new (void)
 	bpd->n_bpath = 0;
 	bpd->n_bpath_max = 16;
 	bpd->moveto_idx = -1;
-	bpd->bpath = g_new (ArtBpath, bpd->n_bpath_max);
+	bpd->bpath = g_new (RsvgBpath, bpd->n_bpath_max);
 	
 	return bpd;
 }
 
 RsvgBpathDef *
-rsvg_bpath_def_new_from (ArtBpath *path)
+rsvg_bpath_def_new_from (RsvgBpath *path)
 {
 	RsvgBpathDef *bpd;
 	int i;
 	
 	g_return_val_if_fail (path != NULL, NULL);
 	
-	for (i = 0; path[i].code != ART_END; i++)
+	for (i = 0; path[i].code != RSVG_END; i++)
 		;
 	if (i <= 0)
 		return rsvg_bpath_def_new ();
@@ -65,13 +67,12 @@ rsvg_bpath_def_new_from (ArtBpath *path)
 	bpd->n_bpath = i;
 	bpd->n_bpath_max = i;
 	bpd->moveto_idx = -1;
-	bpd->bpath = g_new (ArtBpath, i);
+	bpd->bpath = g_new (RsvgBpath, i);
 	
-	memcpy (bpd->bpath, path, i * sizeof (ArtBpath));
+	memcpy (bpd->bpath, path, i * sizeof (RsvgBpath));
 	return bpd;
 }
 
-
 void
 rsvg_bpath_def_free (RsvgBpathDef *bpd)
 {
@@ -81,13 +82,10 @@ rsvg_bpath_def_free (RsvgBpathDef *bpd)
 	g_free (bpd);
 }
 
-
-#include <stdio.h>
-
 void
 rsvg_bpath_def_moveto (RsvgBpathDef *bpd, double x, double y)
 {
-	ArtBpath *bpath;
+	RsvgBpath *bpath;
 	int n_bpath;
 	
 	g_return_if_fail (bpd != NULL);
@@ -98,7 +96,7 @@ rsvg_bpath_def_moveto (RsvgBpathDef *bpd, double x, double y)
 	n_bpath = bpd->n_bpath;
 
 	if (n_bpath > 0)
-		if (bpath[n_bpath - 1].code == ART_MOVETO_OPEN)
+		if (bpath[n_bpath - 1].code == RSVG_MOVETO_OPEN)
 			{
 				bpath[n_bpath - 1].x3 = x;
 				bpath[n_bpath - 1].y3 = y;
@@ -110,9 +108,9 @@ rsvg_bpath_def_moveto (RsvgBpathDef *bpd, double x, double y)
 	
 	if (n_bpath == bpd->n_bpath_max)
 		bpd->bpath = g_realloc (bpd->bpath,
-								(bpd->n_bpath_max <<= 1) * sizeof (ArtBpath));
+								(bpd->n_bpath_max <<= 1) * sizeof (RsvgBpath));
 	bpath = bpd->bpath;
-	bpath[n_bpath].code = ART_MOVETO_OPEN;
+	bpath[n_bpath].code = RSVG_MOVETO_OPEN;
 	bpath[n_bpath].x3 = x;
 	bpath[n_bpath].y3 = y;
 	bpd->moveto_idx = n_bpath;	
@@ -121,7 +119,7 @@ rsvg_bpath_def_moveto (RsvgBpathDef *bpd, double x, double y)
 void
 rsvg_bpath_def_lineto (RsvgBpathDef *bpd, double x, double y)
 {
-	ArtBpath *bpath;
+	RsvgBpath *bpath;
 	int n_bpath;
 	
 	g_return_if_fail (bpd != NULL);
@@ -131,9 +129,9 @@ rsvg_bpath_def_lineto (RsvgBpathDef *bpd, double x, double y)
 	
 	if (n_bpath == bpd->n_bpath_max)
 		bpd->bpath = g_realloc (bpd->bpath,
-								(bpd->n_bpath_max <<= 1) * sizeof (ArtBpath));
+								(bpd->n_bpath_max <<= 1) * sizeof (RsvgBpath));
 	bpath = bpd->bpath;
-	bpath[n_bpath].code = ART_LINETO;
+	bpath[n_bpath].code = RSVG_LINETO;
 	bpath[n_bpath].x3 = x;
 	bpath[n_bpath].y3 = y;
 }
@@ -141,7 +139,7 @@ rsvg_bpath_def_lineto (RsvgBpathDef *bpd, double x, double y)
 void
 rsvg_bpath_def_curveto (RsvgBpathDef *bpd, double x1, double y1, double x2, double y2, double x3, double y3)
 {
-	ArtBpath *bpath;
+	RsvgBpath *bpath;
 	int n_bpath;
   
 	g_return_if_fail (bpd != NULL);
@@ -151,9 +149,9 @@ rsvg_bpath_def_curveto (RsvgBpathDef *bpd, double x1, double y1, double x2, doub
 	
 	if (n_bpath == bpd->n_bpath_max)
 		bpd->bpath = g_realloc (bpd->bpath,
-								(bpd->n_bpath_max <<= 1) * sizeof (ArtBpath));
+								(bpd->n_bpath_max <<= 1) * sizeof (RsvgBpath));
 	bpath = bpd->bpath;
-	bpath[n_bpath].code = ART_CURVETO;
+	bpath[n_bpath].code = RSVG_CURVETO;
 	bpath[n_bpath].x1 = x1;
 	bpath[n_bpath].y1 = y1;
 	bpath[n_bpath].x2 = x2;
@@ -165,17 +163,14 @@ rsvg_bpath_def_curveto (RsvgBpathDef *bpd, double x1, double y1, double x2, doub
 static void
 rsvg_bpath_def_replicate (RsvgBpathDef *bpd, int index)
 {
-	ArtBpath *bpath;
+	RsvgBpath *bpath;
 	int n_bpath;
   
-	g_return_if_fail (bpd != NULL);
-	g_return_if_fail (bpd->moveto_idx >= 0);
-	
 	n_bpath = bpd->n_bpath++;
 	
 	if (n_bpath == bpd->n_bpath_max)
 		bpd->bpath = g_realloc (bpd->bpath,
-								(bpd->n_bpath_max <<= 1) * sizeof (ArtBpath));
+								(bpd->n_bpath_max <<= 1) * sizeof (RsvgBpath));
 	bpath = bpd->bpath;
 	bpath[n_bpath] = bpath[index];
 }
@@ -183,7 +178,7 @@ rsvg_bpath_def_replicate (RsvgBpathDef *bpd, int index)
 void
 rsvg_bpath_def_closepath (RsvgBpathDef *bpd)
 {
-	ArtBpath *bpath;
+	RsvgBpath *bpath;
 	int n_bpath;
 	
 	g_return_if_fail (bpd != NULL);
@@ -199,10 +194,12 @@ rsvg_bpath_def_closepath (RsvgBpathDef *bpd)
 		{
 			rsvg_bpath_def_lineto (bpd, bpath[bpd->moveto_idx].x3,
 								   bpath[bpd->moveto_idx].y3);
-			bpath = bpd->bpath;
 		}
+
 	rsvg_bpath_def_replicate (bpd, bpd->moveto_idx);
-	bpath[bpd->moveto_idx].code = ART_MOVETO;
+	bpath = bpd->bpath;
+
+	bpath[bpd->moveto_idx].code = RSVG_MOVETO;
 	bpd->moveto_idx = -1;
 }
 
@@ -217,6 +214,6 @@ rsvg_bpath_def_art_finish (RsvgBpathDef *bpd)
 	
 	if (n_bpath == bpd->n_bpath_max)
 		bpd->bpath = g_realloc (bpd->bpath,
-								(bpd->n_bpath_max <<= 1) * sizeof (ArtBpath));
-	bpd->bpath[n_bpath].code = ART_END;
+								(bpd->n_bpath_max <<= 1) * sizeof (RsvgBpath));
+	bpd->bpath[n_bpath].code = RSVG_END;
 }
