@@ -145,12 +145,14 @@ _rsvg_node_poly_draw(RsvgNode * self, RsvgDrawingCtx *ctx,
 					 int dominate)
 {
 	RsvgNodePoly * poly = (RsvgNodePoly *)self;
+	gsize i;
+	GString * d;
+
 	/* represent as a "moveto, lineto*, close" path */  
 	if (poly->pointlist_len < 2)
 		return;
 
-	gsize i;
-	GString * d = g_string_new ("");
+	d = g_string_new (NULL);
 	g_string_append_printf (d, "M %f %f ", poly->pointlist[0], poly->pointlist[1] );
 	
 	for (i = 2; i < poly->pointlist_len; i += 2)
